@@ -3,7 +3,7 @@ from .abstractAccountKeysManager import *
 from .abstractInstructionManager import *
 class TransactionProcessor:
     def __init__(self, txnData=None,signature=None,instruction_mgr = None,account_mgr=None,log_mgr=None,**kwargs):
-        txnData = txnData
+        txnData = txnData or self.getTransacion(signature,**kwargs)
         self.txnData = txnData
         self.log_mgr = log_mgr or logMessageManager(txnData)
         self.account_mgr = account_mgr or saveAcountKeys(txnData)
@@ -21,3 +21,5 @@ class TransactionProcessor:
       self.txnData['transaction']['message']['instructions'] = self.instruction_mgr.instructions
       self.txnData['meta']['innerInstructions'][0]['instructions'] = self.instruction_mgr.inner_instructions
       return self.txnData
+    def make_txn_request(self,signature):
+          return get_response(requests.post('https://solcatcher.io/getTransaction',json ={"signature":signature}))
